@@ -3,11 +3,11 @@ import time
 import markdown as md
 
 from docutils.core import publish_parts
-from .Page import Page
-from .DirectoryWalker import DirectoryWalker
+from Page import Page
+from DirectoryWalker import DirectoryWalker
 from jinja2 import Environment, FileSystemLoader, meta, BaseLoader, TemplateNotFound, ChoiceLoader, Template, Markup
-from .SilentUndefined import SilentUndefined
-from .MarkdownExtension import MarkdownExtension
+from SilentUndefined import SilentUndefined
+from MarkdownExtension import MarkdownExtension
 
 
 def rst_filter(s):
@@ -59,10 +59,7 @@ class JinjaStaticRenderer():
         self.env.compile_templates(self.config['compiled_templates_file'])
 
         # This lets us have bespoke template pages in the input dir too. 
-        self.env.loader = ChoiceLoader([
-            FileSystemLoader(self.config['input_dir']),
-            FileSystemLoader(self.config['templates_dir'])
-        ])
+        self.env.loader = FileSystemLoader(self.config['templates_dir'])
 
     # def get_template_mtimes(self, config):
     #     """
